#include <libint2.h>

#ifdef __cplusplus
extern "C" {
#endif
void OSVRRP0InBra_aB_p__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(const Libint_t* inteval, LIBINT2_REALTYPE* target, const LIBINT2_REALTYPE* src0, const LIBINT2_REALTYPE* src1, const LIBINT2_REALTYPE* src2) {

LIBINT2_REALTYPE*const  stack = target;
{
const int hsi = 0;
{
const int lsi = 0;
{
const int vi = 0;
LIBINT2_REALTYPE fp157;
fp157 = 4 * inteval->oo2ze[vi];
LIBINT2_REALTYPE fp156;
fp156 = fp157 * src2[((hsi*15+6)*1+lsi)*1];
LIBINT2_REALTYPE fp159;
fp159 = inteval->WP_y[vi] * src1[((hsi*21+10)*1+lsi)*1];
LIBINT2_REALTYPE fp160;
fp160 = inteval->PA_y[vi] * src0[((hsi*21+10)*1+lsi)*1];
LIBINT2_REALTYPE fp158;
fp158 = fp160 + fp159;
LIBINT2_REALTYPE fp155;
fp155 = fp158 + fp156;
target[((hsi*63+31)*1+lsi)*1] = fp155;
LIBINT2_REALTYPE fp162;
fp162 = inteval->WP_y[vi] * src1[((hsi*21+9)*1+lsi)*1];
LIBINT2_REALTYPE fp163;
fp163 = inteval->PA_y[vi] * src0[((hsi*21+9)*1+lsi)*1];
LIBINT2_REALTYPE fp161;
fp161 = fp163 + fp162;
target[((hsi*63+30)*1+lsi)*1] = fp161;
LIBINT2_REALTYPE fp165;
fp165 = inteval->oo2ze[vi] * src2[((hsi*15+5)*1+lsi)*1];
LIBINT2_REALTYPE fp167;
fp167 = inteval->WP_y[vi] * src1[((hsi*21+8)*1+lsi)*1];
LIBINT2_REALTYPE fp168;
fp168 = inteval->PA_y[vi] * src0[((hsi*21+8)*1+lsi)*1];
LIBINT2_REALTYPE fp166;
fp166 = fp168 + fp167;
LIBINT2_REALTYPE fp164;
fp164 = fp166 + fp165;
target[((hsi*63+29)*1+lsi)*1] = fp164;
LIBINT2_REALTYPE fp171;
fp171 = 2 * inteval->oo2ze[vi];
LIBINT2_REALTYPE fp170;
fp170 = fp171 * src2[((hsi*15+4)*1+lsi)*1];
LIBINT2_REALTYPE fp173;
fp173 = inteval->WP_y[vi] * src1[((hsi*21+7)*1+lsi)*1];
LIBINT2_REALTYPE fp174;
fp174 = inteval->PA_y[vi] * src0[((hsi*21+7)*1+lsi)*1];
LIBINT2_REALTYPE fp172;
fp172 = fp174 + fp173;
LIBINT2_REALTYPE fp169;
fp169 = fp172 + fp170;
target[((hsi*63+28)*1+lsi)*1] = fp169;
LIBINT2_REALTYPE fp177;
fp177 = 3 * inteval->oo2ze[vi];
LIBINT2_REALTYPE fp176;
fp176 = fp177 * src2[((hsi*15+3)*1+lsi)*1];
LIBINT2_REALTYPE fp179;
fp179 = inteval->WP_y[vi] * src1[((hsi*21+6)*1+lsi)*1];
LIBINT2_REALTYPE fp180;
fp180 = inteval->PA_y[vi] * src0[((hsi*21+6)*1+lsi)*1];
LIBINT2_REALTYPE fp178;
fp178 = fp180 + fp179;
LIBINT2_REALTYPE fp175;
fp175 = fp178 + fp176;
target[((hsi*63+27)*1+lsi)*1] = fp175;
LIBINT2_REALTYPE fp182;
fp182 = inteval->WP_y[vi] * src1[((hsi*21+5)*1+lsi)*1];
LIBINT2_REALTYPE fp183;
fp183 = inteval->PA_y[vi] * src0[((hsi*21+5)*1+lsi)*1];
LIBINT2_REALTYPE fp181;
fp181 = fp183 + fp182;
target[((hsi*63+26)*1+lsi)*1] = fp181;
LIBINT2_REALTYPE fp185;
fp185 = inteval->oo2ze[vi] * src2[((hsi*15+2)*1+lsi)*1];
LIBINT2_REALTYPE fp187;
fp187 = inteval->WP_y[vi] * src1[((hsi*21+4)*1+lsi)*1];
LIBINT2_REALTYPE fp188;
fp188 = inteval->PA_y[vi] * src0[((hsi*21+4)*1+lsi)*1];
LIBINT2_REALTYPE fp186;
fp186 = fp188 + fp187;
LIBINT2_REALTYPE fp184;
fp184 = fp186 + fp185;
target[((hsi*63+25)*1+lsi)*1] = fp184;
LIBINT2_REALTYPE fp191;
fp191 = 2 * inteval->oo2ze[vi];
LIBINT2_REALTYPE fp190;
fp190 = fp191 * src2[((hsi*15+1)*1+lsi)*1];
LIBINT2_REALTYPE fp193;
fp193 = inteval->WP_y[vi] * src1[((hsi*21+3)*1+lsi)*1];
LIBINT2_REALTYPE fp194;
fp194 = inteval->PA_y[vi] * src0[((hsi*21+3)*1+lsi)*1];
LIBINT2_REALTYPE fp192;
fp192 = fp194 + fp193;
LIBINT2_REALTYPE fp189;
fp189 = fp192 + fp190;
target[((hsi*63+24)*1+lsi)*1] = fp189;
LIBINT2_REALTYPE fp196;
fp196 = inteval->WP_y[vi] * src1[((hsi*21+2)*1+lsi)*1];
LIBINT2_REALTYPE fp197;
fp197 = inteval->PA_y[vi] * src0[((hsi*21+2)*1+lsi)*1];
LIBINT2_REALTYPE fp195;
fp195 = fp197 + fp196;
target[((hsi*63+23)*1+lsi)*1] = fp195;
LIBINT2_REALTYPE fp199;
fp199 = inteval->oo2ze[vi] * src2[((hsi*15+0)*1+lsi)*1];
LIBINT2_REALTYPE fp201;
fp201 = inteval->WP_y[vi] * src1[((hsi*21+1)*1+lsi)*1];
LIBINT2_REALTYPE fp202;
fp202 = inteval->PA_y[vi] * src0[((hsi*21+1)*1+lsi)*1];
LIBINT2_REALTYPE fp200;
fp200 = fp202 + fp201;
LIBINT2_REALTYPE fp198;
fp198 = fp200 + fp199;
target[((hsi*63+22)*1+lsi)*1] = fp198;
LIBINT2_REALTYPE fp204;
fp204 = inteval->WP_y[vi] * src1[((hsi*21+0)*1+lsi)*1];
LIBINT2_REALTYPE fp205;
fp205 = inteval->PA_y[vi] * src0[((hsi*21+0)*1+lsi)*1];
LIBINT2_REALTYPE fp203;
fp203 = fp205 + fp204;
target[((hsi*63+21)*1+lsi)*1] = fp203;
LIBINT2_REALTYPE fp207;
fp207 = inteval->WP_x[vi] * src1[((hsi*21+20)*1+lsi)*1];
LIBINT2_REALTYPE fp208;
fp208 = inteval->PA_x[vi] * src0[((hsi*21+20)*1+lsi)*1];
LIBINT2_REALTYPE fp206;
fp206 = fp208 + fp207;
target[((hsi*63+20)*1+lsi)*1] = fp206;
LIBINT2_REALTYPE fp210;
fp210 = inteval->WP_x[vi] * src1[((hsi*21+19)*1+lsi)*1];
LIBINT2_REALTYPE fp211;
fp211 = inteval->PA_x[vi] * src0[((hsi*21+19)*1+lsi)*1];
LIBINT2_REALTYPE fp209;
fp209 = fp211 + fp210;
target[((hsi*63+19)*1+lsi)*1] = fp209;
LIBINT2_REALTYPE fp213;
fp213 = inteval->WP_x[vi] * src1[((hsi*21+18)*1+lsi)*1];
LIBINT2_REALTYPE fp214;
fp214 = inteval->PA_x[vi] * src0[((hsi*21+18)*1+lsi)*1];
LIBINT2_REALTYPE fp212;
fp212 = fp214 + fp213;
target[((hsi*63+18)*1+lsi)*1] = fp212;
LIBINT2_REALTYPE fp216;
fp216 = inteval->WP_x[vi] * src1[((hsi*21+17)*1+lsi)*1];
LIBINT2_REALTYPE fp217;
fp217 = inteval->PA_x[vi] * src0[((hsi*21+17)*1+lsi)*1];
LIBINT2_REALTYPE fp215;
fp215 = fp217 + fp216;
target[((hsi*63+17)*1+lsi)*1] = fp215;
LIBINT2_REALTYPE fp219;
fp219 = inteval->WP_x[vi] * src1[((hsi*21+16)*1+lsi)*1];
LIBINT2_REALTYPE fp220;
fp220 = inteval->PA_x[vi] * src0[((hsi*21+16)*1+lsi)*1];
LIBINT2_REALTYPE fp218;
fp218 = fp220 + fp219;
target[((hsi*63+16)*1+lsi)*1] = fp218;
LIBINT2_REALTYPE fp222;
fp222 = inteval->WP_x[vi] * src1[((hsi*21+15)*1+lsi)*1];
LIBINT2_REALTYPE fp223;
fp223 = inteval->PA_x[vi] * src0[((hsi*21+15)*1+lsi)*1];
LIBINT2_REALTYPE fp221;
fp221 = fp223 + fp222;
target[((hsi*63+15)*1+lsi)*1] = fp221;
LIBINT2_REALTYPE fp225;
fp225 = inteval->oo2ze[vi] * src2[((hsi*15+14)*1+lsi)*1];
LIBINT2_REALTYPE fp227;
fp227 = inteval->WP_x[vi] * src1[((hsi*21+14)*1+lsi)*1];
LIBINT2_REALTYPE fp228;
fp228 = inteval->PA_x[vi] * src0[((hsi*21+14)*1+lsi)*1];
LIBINT2_REALTYPE fp226;
fp226 = fp228 + fp227;
LIBINT2_REALTYPE fp224;
fp224 = fp226 + fp225;
target[((hsi*63+14)*1+lsi)*1] = fp224;
LIBINT2_REALTYPE fp230;
fp230 = inteval->oo2ze[vi] * src2[((hsi*15+13)*1+lsi)*1];
LIBINT2_REALTYPE fp232;
fp232 = inteval->WP_x[vi] * src1[((hsi*21+13)*1+lsi)*1];
LIBINT2_REALTYPE fp233;
fp233 = inteval->PA_x[vi] * src0[((hsi*21+13)*1+lsi)*1];
LIBINT2_REALTYPE fp231;
fp231 = fp233 + fp232;
LIBINT2_REALTYPE fp229;
fp229 = fp231 + fp230;
target[((hsi*63+13)*1+lsi)*1] = fp229;
LIBINT2_REALTYPE fp235;
fp235 = inteval->oo2ze[vi] * src2[((hsi*15+12)*1+lsi)*1];
LIBINT2_REALTYPE fp237;
fp237 = inteval->WP_x[vi] * src1[((hsi*21+12)*1+lsi)*1];
LIBINT2_REALTYPE fp238;
fp238 = inteval->PA_x[vi] * src0[((hsi*21+12)*1+lsi)*1];
LIBINT2_REALTYPE fp236;
fp236 = fp238 + fp237;
LIBINT2_REALTYPE fp234;
fp234 = fp236 + fp235;
target[((hsi*63+12)*1+lsi)*1] = fp234;
LIBINT2_REALTYPE fp240;
fp240 = inteval->oo2ze[vi] * src2[((hsi*15+11)*1+lsi)*1];
LIBINT2_REALTYPE fp242;
fp242 = inteval->WP_x[vi] * src1[((hsi*21+11)*1+lsi)*1];
LIBINT2_REALTYPE fp243;
fp243 = inteval->PA_x[vi] * src0[((hsi*21+11)*1+lsi)*1];
LIBINT2_REALTYPE fp241;
fp241 = fp243 + fp242;
LIBINT2_REALTYPE fp239;
fp239 = fp241 + fp240;
target[((hsi*63+11)*1+lsi)*1] = fp239;
LIBINT2_REALTYPE fp245;
fp245 = inteval->oo2ze[vi] * src2[((hsi*15+10)*1+lsi)*1];
LIBINT2_REALTYPE fp247;
fp247 = inteval->WP_x[vi] * src1[((hsi*21+10)*1+lsi)*1];
LIBINT2_REALTYPE fp248;
fp248 = inteval->PA_x[vi] * src0[((hsi*21+10)*1+lsi)*1];
LIBINT2_REALTYPE fp246;
fp246 = fp248 + fp247;
LIBINT2_REALTYPE fp244;
fp244 = fp246 + fp245;
target[((hsi*63+10)*1+lsi)*1] = fp244;
LIBINT2_REALTYPE fp251;
fp251 = 2 * inteval->oo2ze[vi];
LIBINT2_REALTYPE fp250;
fp250 = fp251 * src2[((hsi*15+9)*1+lsi)*1];
LIBINT2_REALTYPE fp253;
fp253 = inteval->WP_x[vi] * src1[((hsi*21+9)*1+lsi)*1];
LIBINT2_REALTYPE fp254;
fp254 = inteval->PA_x[vi] * src0[((hsi*21+9)*1+lsi)*1];
LIBINT2_REALTYPE fp252;
fp252 = fp254 + fp253;
LIBINT2_REALTYPE fp249;
fp249 = fp252 + fp250;
target[((hsi*63+9)*1+lsi)*1] = fp249;
LIBINT2_REALTYPE fp257;
fp257 = 2 * inteval->oo2ze[vi];
LIBINT2_REALTYPE fp256;
fp256 = fp257 * src2[((hsi*15+8)*1+lsi)*1];
LIBINT2_REALTYPE fp259;
fp259 = inteval->WP_x[vi] * src1[((hsi*21+8)*1+lsi)*1];
LIBINT2_REALTYPE fp260;
fp260 = inteval->PA_x[vi] * src0[((hsi*21+8)*1+lsi)*1];
LIBINT2_REALTYPE fp258;
fp258 = fp260 + fp259;
LIBINT2_REALTYPE fp255;
fp255 = fp258 + fp256;
target[((hsi*63+8)*1+lsi)*1] = fp255;
LIBINT2_REALTYPE fp263;
fp263 = 2 * inteval->oo2ze[vi];
LIBINT2_REALTYPE fp262;
fp262 = fp263 * src2[((hsi*15+7)*1+lsi)*1];
LIBINT2_REALTYPE fp265;
fp265 = inteval->WP_x[vi] * src1[((hsi*21+7)*1+lsi)*1];
LIBINT2_REALTYPE fp266;
fp266 = inteval->PA_x[vi] * src0[((hsi*21+7)*1+lsi)*1];
LIBINT2_REALTYPE fp264;
fp264 = fp266 + fp265;
LIBINT2_REALTYPE fp261;
fp261 = fp264 + fp262;
target[((hsi*63+7)*1+lsi)*1] = fp261;
LIBINT2_REALTYPE fp269;
fp269 = 2 * inteval->oo2ze[vi];
LIBINT2_REALTYPE fp268;
fp268 = fp269 * src2[((hsi*15+6)*1+lsi)*1];
LIBINT2_REALTYPE fp271;
fp271 = inteval->WP_x[vi] * src1[((hsi*21+6)*1+lsi)*1];
LIBINT2_REALTYPE fp272;
fp272 = inteval->PA_x[vi] * src0[((hsi*21+6)*1+lsi)*1];
LIBINT2_REALTYPE fp270;
fp270 = fp272 + fp271;
LIBINT2_REALTYPE fp267;
fp267 = fp270 + fp268;
target[((hsi*63+6)*1+lsi)*1] = fp267;
LIBINT2_REALTYPE fp275;
fp275 = 3 * inteval->oo2ze[vi];
LIBINT2_REALTYPE fp274;
fp274 = fp275 * src2[((hsi*15+5)*1+lsi)*1];
LIBINT2_REALTYPE fp277;
fp277 = inteval->WP_x[vi] * src1[((hsi*21+5)*1+lsi)*1];
LIBINT2_REALTYPE fp278;
fp278 = inteval->PA_x[vi] * src0[((hsi*21+5)*1+lsi)*1];
LIBINT2_REALTYPE fp276;
fp276 = fp278 + fp277;
LIBINT2_REALTYPE fp273;
fp273 = fp276 + fp274;
target[((hsi*63+5)*1+lsi)*1] = fp273;
LIBINT2_REALTYPE fp281;
fp281 = 3 * inteval->oo2ze[vi];
LIBINT2_REALTYPE fp280;
fp280 = fp281 * src2[((hsi*15+4)*1+lsi)*1];
LIBINT2_REALTYPE fp283;
fp283 = inteval->WP_x[vi] * src1[((hsi*21+4)*1+lsi)*1];
LIBINT2_REALTYPE fp284;
fp284 = inteval->PA_x[vi] * src0[((hsi*21+4)*1+lsi)*1];
LIBINT2_REALTYPE fp282;
fp282 = fp284 + fp283;
LIBINT2_REALTYPE fp279;
fp279 = fp282 + fp280;
target[((hsi*63+4)*1+lsi)*1] = fp279;
LIBINT2_REALTYPE fp287;
fp287 = 3 * inteval->oo2ze[vi];
LIBINT2_REALTYPE fp286;
fp286 = fp287 * src2[((hsi*15+3)*1+lsi)*1];
LIBINT2_REALTYPE fp289;
fp289 = inteval->WP_x[vi] * src1[((hsi*21+3)*1+lsi)*1];
LIBINT2_REALTYPE fp290;
fp290 = inteval->PA_x[vi] * src0[((hsi*21+3)*1+lsi)*1];
LIBINT2_REALTYPE fp288;
fp288 = fp290 + fp289;
LIBINT2_REALTYPE fp285;
fp285 = fp288 + fp286;
target[((hsi*63+3)*1+lsi)*1] = fp285;
LIBINT2_REALTYPE fp293;
fp293 = 4 * inteval->oo2ze[vi];
LIBINT2_REALTYPE fp292;
fp292 = fp293 * src2[((hsi*15+2)*1+lsi)*1];
LIBINT2_REALTYPE fp295;
fp295 = inteval->WP_x[vi] * src1[((hsi*21+2)*1+lsi)*1];
LIBINT2_REALTYPE fp296;
fp296 = inteval->PA_x[vi] * src0[((hsi*21+2)*1+lsi)*1];
LIBINT2_REALTYPE fp294;
fp294 = fp296 + fp295;
LIBINT2_REALTYPE fp291;
fp291 = fp294 + fp292;
target[((hsi*63+2)*1+lsi)*1] = fp291;
LIBINT2_REALTYPE fp299;
fp299 = 4 * inteval->oo2ze[vi];
LIBINT2_REALTYPE fp298;
fp298 = fp299 * src2[((hsi*15+1)*1+lsi)*1];
LIBINT2_REALTYPE fp301;
fp301 = inteval->WP_x[vi] * src1[((hsi*21+1)*1+lsi)*1];
LIBINT2_REALTYPE fp302;
fp302 = inteval->PA_x[vi] * src0[((hsi*21+1)*1+lsi)*1];
LIBINT2_REALTYPE fp300;
fp300 = fp302 + fp301;
LIBINT2_REALTYPE fp297;
fp297 = fp300 + fp298;
target[((hsi*63+1)*1+lsi)*1] = fp297;
LIBINT2_REALTYPE fp305;
fp305 = 5 * inteval->oo2ze[vi];
LIBINT2_REALTYPE fp304;
fp304 = fp305 * src2[((hsi*15+0)*1+lsi)*1];
LIBINT2_REALTYPE fp307;
fp307 = inteval->WP_x[vi] * src1[((hsi*21+0)*1+lsi)*1];
LIBINT2_REALTYPE fp308;
fp308 = inteval->PA_x[vi] * src0[((hsi*21+0)*1+lsi)*1];
LIBINT2_REALTYPE fp306;
fp306 = fp308 + fp307;
LIBINT2_REALTYPE fp303;
fp303 = fp306 + fp304;
target[((hsi*63+0)*1+lsi)*1] = fp303;
LIBINT2_REALTYPE fp2;
fp2 = 5 * inteval->oo2ze[vi];
LIBINT2_REALTYPE fp1;
fp1 = fp2 * src2[((hsi*15+14)*1+lsi)*1];
LIBINT2_REALTYPE fp4;
fp4 = inteval->WP_z[vi] * src1[((hsi*21+20)*1+lsi)*1];
LIBINT2_REALTYPE fp5;
fp5 = inteval->PA_z[vi] * src0[((hsi*21+20)*1+lsi)*1];
LIBINT2_REALTYPE fp3;
fp3 = fp5 + fp4;
LIBINT2_REALTYPE fp0;
fp0 = fp3 + fp1;
target[((hsi*63+62)*1+lsi)*1] = fp0;
LIBINT2_REALTYPE fp8;
fp8 = 4 * inteval->oo2ze[vi];
LIBINT2_REALTYPE fp7;
fp7 = fp8 * src2[((hsi*15+13)*1+lsi)*1];
LIBINT2_REALTYPE fp10;
fp10 = inteval->WP_z[vi] * src1[((hsi*21+19)*1+lsi)*1];
LIBINT2_REALTYPE fp11;
fp11 = inteval->PA_z[vi] * src0[((hsi*21+19)*1+lsi)*1];
LIBINT2_REALTYPE fp9;
fp9 = fp11 + fp10;
LIBINT2_REALTYPE fp6;
fp6 = fp9 + fp7;
target[((hsi*63+61)*1+lsi)*1] = fp6;
LIBINT2_REALTYPE fp14;
fp14 = 3 * inteval->oo2ze[vi];
LIBINT2_REALTYPE fp13;
fp13 = fp14 * src2[((hsi*15+12)*1+lsi)*1];
LIBINT2_REALTYPE fp16;
fp16 = inteval->WP_z[vi] * src1[((hsi*21+18)*1+lsi)*1];
LIBINT2_REALTYPE fp17;
fp17 = inteval->PA_z[vi] * src0[((hsi*21+18)*1+lsi)*1];
LIBINT2_REALTYPE fp15;
fp15 = fp17 + fp16;
LIBINT2_REALTYPE fp12;
fp12 = fp15 + fp13;
target[((hsi*63+60)*1+lsi)*1] = fp12;
LIBINT2_REALTYPE fp20;
fp20 = 2 * inteval->oo2ze[vi];
LIBINT2_REALTYPE fp19;
fp19 = fp20 * src2[((hsi*15+11)*1+lsi)*1];
LIBINT2_REALTYPE fp22;
fp22 = inteval->WP_z[vi] * src1[((hsi*21+17)*1+lsi)*1];
LIBINT2_REALTYPE fp23;
fp23 = inteval->PA_z[vi] * src0[((hsi*21+17)*1+lsi)*1];
LIBINT2_REALTYPE fp21;
fp21 = fp23 + fp22;
LIBINT2_REALTYPE fp18;
fp18 = fp21 + fp19;
target[((hsi*63+59)*1+lsi)*1] = fp18;
LIBINT2_REALTYPE fp25;
fp25 = inteval->oo2ze[vi] * src2[((hsi*15+10)*1+lsi)*1];
LIBINT2_REALTYPE fp27;
fp27 = inteval->WP_z[vi] * src1[((hsi*21+16)*1+lsi)*1];
LIBINT2_REALTYPE fp28;
fp28 = inteval->PA_z[vi] * src0[((hsi*21+16)*1+lsi)*1];
LIBINT2_REALTYPE fp26;
fp26 = fp28 + fp27;
LIBINT2_REALTYPE fp24;
fp24 = fp26 + fp25;
target[((hsi*63+58)*1+lsi)*1] = fp24;
LIBINT2_REALTYPE fp30;
fp30 = inteval->WP_z[vi] * src1[((hsi*21+15)*1+lsi)*1];
LIBINT2_REALTYPE fp31;
fp31 = inteval->PA_z[vi] * src0[((hsi*21+15)*1+lsi)*1];
LIBINT2_REALTYPE fp29;
fp29 = fp31 + fp30;
target[((hsi*63+57)*1+lsi)*1] = fp29;
LIBINT2_REALTYPE fp34;
fp34 = 4 * inteval->oo2ze[vi];
LIBINT2_REALTYPE fp33;
fp33 = fp34 * src2[((hsi*15+9)*1+lsi)*1];
LIBINT2_REALTYPE fp36;
fp36 = inteval->WP_z[vi] * src1[((hsi*21+14)*1+lsi)*1];
LIBINT2_REALTYPE fp37;
fp37 = inteval->PA_z[vi] * src0[((hsi*21+14)*1+lsi)*1];
LIBINT2_REALTYPE fp35;
fp35 = fp37 + fp36;
LIBINT2_REALTYPE fp32;
fp32 = fp35 + fp33;
target[((hsi*63+56)*1+lsi)*1] = fp32;
LIBINT2_REALTYPE fp40;
fp40 = 3 * inteval->oo2ze[vi];
LIBINT2_REALTYPE fp39;
fp39 = fp40 * src2[((hsi*15+8)*1+lsi)*1];
LIBINT2_REALTYPE fp42;
fp42 = inteval->WP_z[vi] * src1[((hsi*21+13)*1+lsi)*1];
LIBINT2_REALTYPE fp43;
fp43 = inteval->PA_z[vi] * src0[((hsi*21+13)*1+lsi)*1];
LIBINT2_REALTYPE fp41;
fp41 = fp43 + fp42;
LIBINT2_REALTYPE fp38;
fp38 = fp41 + fp39;
target[((hsi*63+55)*1+lsi)*1] = fp38;
LIBINT2_REALTYPE fp46;
fp46 = 2 * inteval->oo2ze[vi];
LIBINT2_REALTYPE fp45;
fp45 = fp46 * src2[((hsi*15+7)*1+lsi)*1];
LIBINT2_REALTYPE fp48;
fp48 = inteval->WP_z[vi] * src1[((hsi*21+12)*1+lsi)*1];
LIBINT2_REALTYPE fp49;
fp49 = inteval->PA_z[vi] * src0[((hsi*21+12)*1+lsi)*1];
LIBINT2_REALTYPE fp47;
fp47 = fp49 + fp48;
LIBINT2_REALTYPE fp44;
fp44 = fp47 + fp45;
target[((hsi*63+54)*1+lsi)*1] = fp44;
LIBINT2_REALTYPE fp51;
fp51 = inteval->oo2ze[vi] * src2[((hsi*15+6)*1+lsi)*1];
LIBINT2_REALTYPE fp53;
fp53 = inteval->WP_z[vi] * src1[((hsi*21+11)*1+lsi)*1];
LIBINT2_REALTYPE fp54;
fp54 = inteval->PA_z[vi] * src0[((hsi*21+11)*1+lsi)*1];
LIBINT2_REALTYPE fp52;
fp52 = fp54 + fp53;
LIBINT2_REALTYPE fp50;
fp50 = fp52 + fp51;
target[((hsi*63+53)*1+lsi)*1] = fp50;
LIBINT2_REALTYPE fp56;
fp56 = inteval->WP_z[vi] * src1[((hsi*21+10)*1+lsi)*1];
LIBINT2_REALTYPE fp57;
fp57 = inteval->PA_z[vi] * src0[((hsi*21+10)*1+lsi)*1];
LIBINT2_REALTYPE fp55;
fp55 = fp57 + fp56;
target[((hsi*63+52)*1+lsi)*1] = fp55;
LIBINT2_REALTYPE fp60;
fp60 = 3 * inteval->oo2ze[vi];
LIBINT2_REALTYPE fp59;
fp59 = fp60 * src2[((hsi*15+5)*1+lsi)*1];
LIBINT2_REALTYPE fp62;
fp62 = inteval->WP_z[vi] * src1[((hsi*21+9)*1+lsi)*1];
LIBINT2_REALTYPE fp63;
fp63 = inteval->PA_z[vi] * src0[((hsi*21+9)*1+lsi)*1];
LIBINT2_REALTYPE fp61;
fp61 = fp63 + fp62;
LIBINT2_REALTYPE fp58;
fp58 = fp61 + fp59;
target[((hsi*63+51)*1+lsi)*1] = fp58;
LIBINT2_REALTYPE fp66;
fp66 = 2 * inteval->oo2ze[vi];
LIBINT2_REALTYPE fp65;
fp65 = fp66 * src2[((hsi*15+4)*1+lsi)*1];
LIBINT2_REALTYPE fp68;
fp68 = inteval->WP_z[vi] * src1[((hsi*21+8)*1+lsi)*1];
LIBINT2_REALTYPE fp69;
fp69 = inteval->PA_z[vi] * src0[((hsi*21+8)*1+lsi)*1];
LIBINT2_REALTYPE fp67;
fp67 = fp69 + fp68;
LIBINT2_REALTYPE fp64;
fp64 = fp67 + fp65;
target[((hsi*63+50)*1+lsi)*1] = fp64;
LIBINT2_REALTYPE fp71;
fp71 = inteval->oo2ze[vi] * src2[((hsi*15+3)*1+lsi)*1];
LIBINT2_REALTYPE fp73;
fp73 = inteval->WP_z[vi] * src1[((hsi*21+7)*1+lsi)*1];
LIBINT2_REALTYPE fp74;
fp74 = inteval->PA_z[vi] * src0[((hsi*21+7)*1+lsi)*1];
LIBINT2_REALTYPE fp72;
fp72 = fp74 + fp73;
LIBINT2_REALTYPE fp70;
fp70 = fp72 + fp71;
target[((hsi*63+49)*1+lsi)*1] = fp70;
LIBINT2_REALTYPE fp76;
fp76 = inteval->WP_z[vi] * src1[((hsi*21+6)*1+lsi)*1];
LIBINT2_REALTYPE fp77;
fp77 = inteval->PA_z[vi] * src0[((hsi*21+6)*1+lsi)*1];
LIBINT2_REALTYPE fp75;
fp75 = fp77 + fp76;
target[((hsi*63+48)*1+lsi)*1] = fp75;
LIBINT2_REALTYPE fp80;
fp80 = 2 * inteval->oo2ze[vi];
LIBINT2_REALTYPE fp79;
fp79 = fp80 * src2[((hsi*15+2)*1+lsi)*1];
LIBINT2_REALTYPE fp82;
fp82 = inteval->WP_z[vi] * src1[((hsi*21+5)*1+lsi)*1];
LIBINT2_REALTYPE fp83;
fp83 = inteval->PA_z[vi] * src0[((hsi*21+5)*1+lsi)*1];
LIBINT2_REALTYPE fp81;
fp81 = fp83 + fp82;
LIBINT2_REALTYPE fp78;
fp78 = fp81 + fp79;
target[((hsi*63+47)*1+lsi)*1] = fp78;
LIBINT2_REALTYPE fp85;
fp85 = inteval->oo2ze[vi] * src2[((hsi*15+1)*1+lsi)*1];
LIBINT2_REALTYPE fp87;
fp87 = inteval->WP_z[vi] * src1[((hsi*21+4)*1+lsi)*1];
LIBINT2_REALTYPE fp88;
fp88 = inteval->PA_z[vi] * src0[((hsi*21+4)*1+lsi)*1];
LIBINT2_REALTYPE fp86;
fp86 = fp88 + fp87;
LIBINT2_REALTYPE fp84;
fp84 = fp86 + fp85;
target[((hsi*63+46)*1+lsi)*1] = fp84;
LIBINT2_REALTYPE fp90;
fp90 = inteval->WP_z[vi] * src1[((hsi*21+3)*1+lsi)*1];
LIBINT2_REALTYPE fp91;
fp91 = inteval->PA_z[vi] * src0[((hsi*21+3)*1+lsi)*1];
LIBINT2_REALTYPE fp89;
fp89 = fp91 + fp90;
target[((hsi*63+45)*1+lsi)*1] = fp89;
LIBINT2_REALTYPE fp93;
fp93 = inteval->oo2ze[vi] * src2[((hsi*15+0)*1+lsi)*1];
LIBINT2_REALTYPE fp95;
fp95 = inteval->WP_z[vi] * src1[((hsi*21+2)*1+lsi)*1];
LIBINT2_REALTYPE fp96;
fp96 = inteval->PA_z[vi] * src0[((hsi*21+2)*1+lsi)*1];
LIBINT2_REALTYPE fp94;
fp94 = fp96 + fp95;
LIBINT2_REALTYPE fp92;
fp92 = fp94 + fp93;
target[((hsi*63+44)*1+lsi)*1] = fp92;
LIBINT2_REALTYPE fp98;
fp98 = inteval->WP_z[vi] * src1[((hsi*21+1)*1+lsi)*1];
LIBINT2_REALTYPE fp99;
fp99 = inteval->PA_z[vi] * src0[((hsi*21+1)*1+lsi)*1];
LIBINT2_REALTYPE fp97;
fp97 = fp99 + fp98;
target[((hsi*63+43)*1+lsi)*1] = fp97;
LIBINT2_REALTYPE fp101;
fp101 = inteval->WP_z[vi] * src1[((hsi*21+0)*1+lsi)*1];
LIBINT2_REALTYPE fp102;
fp102 = inteval->PA_z[vi] * src0[((hsi*21+0)*1+lsi)*1];
LIBINT2_REALTYPE fp100;
fp100 = fp102 + fp101;
target[((hsi*63+42)*1+lsi)*1] = fp100;
LIBINT2_REALTYPE fp104;
fp104 = inteval->WP_y[vi] * src1[((hsi*21+20)*1+lsi)*1];
LIBINT2_REALTYPE fp105;
fp105 = inteval->PA_y[vi] * src0[((hsi*21+20)*1+lsi)*1];
LIBINT2_REALTYPE fp103;
fp103 = fp105 + fp104;
target[((hsi*63+41)*1+lsi)*1] = fp103;
LIBINT2_REALTYPE fp107;
fp107 = inteval->oo2ze[vi] * src2[((hsi*15+14)*1+lsi)*1];
LIBINT2_REALTYPE fp109;
fp109 = inteval->WP_y[vi] * src1[((hsi*21+19)*1+lsi)*1];
LIBINT2_REALTYPE fp110;
fp110 = inteval->PA_y[vi] * src0[((hsi*21+19)*1+lsi)*1];
LIBINT2_REALTYPE fp108;
fp108 = fp110 + fp109;
LIBINT2_REALTYPE fp106;
fp106 = fp108 + fp107;
target[((hsi*63+40)*1+lsi)*1] = fp106;
LIBINT2_REALTYPE fp113;
fp113 = 2 * inteval->oo2ze[vi];
LIBINT2_REALTYPE fp112;
fp112 = fp113 * src2[((hsi*15+13)*1+lsi)*1];
LIBINT2_REALTYPE fp115;
fp115 = inteval->WP_y[vi] * src1[((hsi*21+18)*1+lsi)*1];
LIBINT2_REALTYPE fp116;
fp116 = inteval->PA_y[vi] * src0[((hsi*21+18)*1+lsi)*1];
LIBINT2_REALTYPE fp114;
fp114 = fp116 + fp115;
LIBINT2_REALTYPE fp111;
fp111 = fp114 + fp112;
target[((hsi*63+39)*1+lsi)*1] = fp111;
LIBINT2_REALTYPE fp119;
fp119 = 3 * inteval->oo2ze[vi];
LIBINT2_REALTYPE fp118;
fp118 = fp119 * src2[((hsi*15+12)*1+lsi)*1];
LIBINT2_REALTYPE fp121;
fp121 = inteval->WP_y[vi] * src1[((hsi*21+17)*1+lsi)*1];
LIBINT2_REALTYPE fp122;
fp122 = inteval->PA_y[vi] * src0[((hsi*21+17)*1+lsi)*1];
LIBINT2_REALTYPE fp120;
fp120 = fp122 + fp121;
LIBINT2_REALTYPE fp117;
fp117 = fp120 + fp118;
target[((hsi*63+38)*1+lsi)*1] = fp117;
LIBINT2_REALTYPE fp125;
fp125 = 4 * inteval->oo2ze[vi];
LIBINT2_REALTYPE fp124;
fp124 = fp125 * src2[((hsi*15+11)*1+lsi)*1];
LIBINT2_REALTYPE fp127;
fp127 = inteval->WP_y[vi] * src1[((hsi*21+16)*1+lsi)*1];
LIBINT2_REALTYPE fp128;
fp128 = inteval->PA_y[vi] * src0[((hsi*21+16)*1+lsi)*1];
LIBINT2_REALTYPE fp126;
fp126 = fp128 + fp127;
LIBINT2_REALTYPE fp123;
fp123 = fp126 + fp124;
target[((hsi*63+37)*1+lsi)*1] = fp123;
LIBINT2_REALTYPE fp131;
fp131 = 5 * inteval->oo2ze[vi];
LIBINT2_REALTYPE fp130;
fp130 = fp131 * src2[((hsi*15+10)*1+lsi)*1];
LIBINT2_REALTYPE fp133;
fp133 = inteval->WP_y[vi] * src1[((hsi*21+15)*1+lsi)*1];
LIBINT2_REALTYPE fp134;
fp134 = inteval->PA_y[vi] * src0[((hsi*21+15)*1+lsi)*1];
LIBINT2_REALTYPE fp132;
fp132 = fp134 + fp133;
LIBINT2_REALTYPE fp129;
fp129 = fp132 + fp130;
target[((hsi*63+36)*1+lsi)*1] = fp129;
LIBINT2_REALTYPE fp136;
fp136 = inteval->WP_y[vi] * src1[((hsi*21+14)*1+lsi)*1];
LIBINT2_REALTYPE fp137;
fp137 = inteval->PA_y[vi] * src0[((hsi*21+14)*1+lsi)*1];
LIBINT2_REALTYPE fp135;
fp135 = fp137 + fp136;
target[((hsi*63+35)*1+lsi)*1] = fp135;
LIBINT2_REALTYPE fp139;
fp139 = inteval->oo2ze[vi] * src2[((hsi*15+9)*1+lsi)*1];
LIBINT2_REALTYPE fp141;
fp141 = inteval->WP_y[vi] * src1[((hsi*21+13)*1+lsi)*1];
LIBINT2_REALTYPE fp142;
fp142 = inteval->PA_y[vi] * src0[((hsi*21+13)*1+lsi)*1];
LIBINT2_REALTYPE fp140;
fp140 = fp142 + fp141;
LIBINT2_REALTYPE fp138;
fp138 = fp140 + fp139;
target[((hsi*63+34)*1+lsi)*1] = fp138;
LIBINT2_REALTYPE fp145;
fp145 = 2 * inteval->oo2ze[vi];
LIBINT2_REALTYPE fp144;
fp144 = fp145 * src2[((hsi*15+8)*1+lsi)*1];
LIBINT2_REALTYPE fp147;
fp147 = inteval->WP_y[vi] * src1[((hsi*21+12)*1+lsi)*1];
LIBINT2_REALTYPE fp148;
fp148 = inteval->PA_y[vi] * src0[((hsi*21+12)*1+lsi)*1];
LIBINT2_REALTYPE fp146;
fp146 = fp148 + fp147;
LIBINT2_REALTYPE fp143;
fp143 = fp146 + fp144;
target[((hsi*63+33)*1+lsi)*1] = fp143;
LIBINT2_REALTYPE fp151;
fp151 = 3 * inteval->oo2ze[vi];
LIBINT2_REALTYPE fp150;
fp150 = fp151 * src2[((hsi*15+7)*1+lsi)*1];
LIBINT2_REALTYPE fp153;
fp153 = inteval->WP_y[vi] * src1[((hsi*21+11)*1+lsi)*1];
LIBINT2_REALTYPE fp154;
fp154 = inteval->PA_y[vi] * src0[((hsi*21+11)*1+lsi)*1];
LIBINT2_REALTYPE fp152;
fp152 = fp154 + fp153;
LIBINT2_REALTYPE fp149;
fp149 = fp152 + fp150;
target[((hsi*63+32)*1+lsi)*1] = fp149;
}
}
}
const int hsi = 0;
const int lsi = 0;
const int vi = 0;
/** Number of flops = 309 */
}

#ifdef __cplusplus
};
#endif
